#!/bin/bash
PYTHONPATH="" #Set the python path
export PYTHONPATH

bootstrapData_bin="" #Path to the bootstrapData.py file

TRAIN_DATA=$1 # list of data for training
VAL_DATA=$2 # list of validation data

RANK_POWER=20
START_ID=00000000
CROP_SIZE=66
NET_RESOLUTION=16 # the output layer size
CROPS_PER_IMAGE=5
NOISE=4 # Additive gaussioan noise
DoF=2 # Maximum radius of depth of field psf - sampled uniformly
HAND_SHAKE_BLUR_PSF_R=0 #Maximum hand shake psf radius - sampled uniformly 
BORDER_SIZE=5 # Border added to the crop and removed after geometric transformations
ROT_X_SDEV=2
ROT_Y_SDEV=2
ROT_Z_SDEV=1
MIN_PAGE_FOV=5
MAX_PAGE_FOV=15
MB_ANGLE_MIN=35 # min angle in deg of the motion blur vector with the axe X
MB_ANGLE_MAX=80 # max angle in deg of motion blur vector with the ace X
MB_LENGTH_MIN=1 # min length of the motion vector in px (float)
MB_LENGTH_MAX=19 # max length of the motion vector in px (float)
WRITE_IMAGES="" # set "-I" to write images, otherwise set the empty string ""

BASE_NAME="motion_blur_MLength${MB_LENGTH_MIN}_${MB_LENGTH_MAX}_MAngle$_${MB_ANGLE_MIN}_${MB_ANGLE_MAX}_s${CROP_SIZE}_net_res${NET_RESOLUTION}_n${NOISE}_p${DoF}_m${HAND_SHAKE_BLUR_PSF_R}_border_size${BORDER_SIZE}_rX${ROT_X_SDEV}_rY${ROT_Y_SDEV}_rZ${ROT_Z_SDEV}_minpf${MIN_PAGE_FOV}_maxpf${MAX_PAGE_FOV}"
OUT_DIR="" #Path to store the db

echo Processing Train data: $TRAIN_DATA
cat $TRAIN_DATA |\
python $bootstrapData_bin \
	--rank_power $RANK_POWER\
	--start_id $START_ID\
	-s $CROP_SIZE\
	--net_resolution $NET_RESOLUTION\
	--per_image $CROPS_PER_IMAGE\
	-n $NOISE\
	-p $DoF\
	-m $HAND_SHAKE_BLUR_PSF_R\
	--border_size $BORDER_SIZE\
	--rotationX_sdev $ROT_X_SDEV --rotationY_sdev $ROT_Y_SDEV --rotationZ_sdev $ROT_Z_SDEV\
	--min_page_fov $MIN_PAGE_FOV --max_page_fov $MAX_PAGE_FOV\
	-mb\
	-mbamin $MB_ANGLE_MIN -mbamax $MB_ANGLE_MAX\
	-mblmin $MB_LENGTH_MIN -mblmax $MB_LENGTH_MAX\
	--gpu\
	$WRITE_IMAGES\
	-P  "$OUT_DIR/train/${BASE_NAME}.psf"\
	-o  "$OUT_DIR/train/${BASE_NAME}.blur"\
	-O  "$OUT_DIR/train/${BASE_NAME}.orig"\
	> train_${BASE_NAME}.log

echo Processing Val data: $VAL_DATA
cat $VAL_DATA |\
python $bootstrapData_bin \
	--rank_power $RANK_POWER\
	--start_id $START_ID\
	-s $CROP_SIZE\
	--net_resolution $NET_RESOLUTION\
	--per_image $CROPS_PER_IMAGE\
	-n $NOISE\
	-p $DoF\
	-m $HAND_SHAKE_BLUR_PSF_R\
	--border_size $BORDER_SIZE\
	--rotationX_sdev $ROT_X_SDEV --rotationY_sdev $ROT_Y_SDEV --rotationZ_sdev $ROT_Z_SDEV\
	--min_page_fov $MIN_PAGE_FOV --max_page_fov $MAX_PAGE_FOV\
	-mb\
	-mbamin $MB_ANGLE_MIN -mbamax $MB_ANGLE_MAX\
	-mblmin $MB_LENGTH_MIN -mblmax $MB_LENGTH_MAX\
	--gpu\
	$WRITE_IMAGES\
	-P  "$OUT_DIR/val/${BASE_NAME}.psf"\
	-o  "$OUT_DIR/val/${BASE_NAME}.blur"\
	-O  "$OUT_DIR/val/${BASE_NAME}.orig"\
	> val_${BASE_NAME}.log
